==> nextcloud-23.0.5.tgz: nextcloud/apps/password_policy/l10n/es_CL.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La contraseña es una entre las 1,000,000 más comunes. Por favor hazla más única. ",
    "Password is present in compromised password list. Please choose a different password." : "La contraseña está presente en el listado de contraseñas comprometidas. Por favor selecciona una contraseña diferente.",
    "Password needs to contain at least one numeric character." : "La contraseña necesita contener al menos un número.",
    "Password needs to contain at least one special character." : "La contraseña necesita contener al menos un caracter especial.",
    "Password needs to contain at least one lower and one upper case character." : "La contraseña necesita contener al menos una mayúscula y una minúscula.",
    "Password policy" : "Política de contraseñas",
    "Saved" : "Guardado",
    "Forbid common passwords" : "Restringir contraseñas comunes",
    "Enforce upper and lower case characters" : "Imponer caracteres en mayúsculas y minúsculas",
    "Enforce numeric characters" : "Imponer caracteres numéricos",
    "Enforce special characters" : "Imponer caracteres especiales",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verifica la contraseña contra la lista de contraseñas comprometidas de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Esta verificación crea un resumen de la contraseña y envia los primeros 5 caracteres de este resumen al API haveibeenpwned.com para obtener una lista de todos los resumenes que empezan con ellos. Después verfica en la instancia de Nextcloud si la contraseña está en el juego de resultados.",
    "Unknown error" : "Se presentó un error desconocido"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/password_policy/l10n/es_CL.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "La contraseña es una entre las 1,000,000 más comunes. Por favor hazla más única. ",
    "Password is present in compromised password list. Please choose a different password." : "La contraseña está presente en el listado de contraseñas comprometidas. Por favor selecciona una contraseña diferente.",
    "Password needs to contain at least one numeric character." : "La contraseña necesita contener al menos un número.",
    "Password needs to contain at least one special character." : "La contraseña necesita contener al menos un caracter especial.",
    "Password needs to contain at least one lower and one upper case character." : "La contraseña necesita contener al menos una mayúscula y una minúscula.",
    "Password policy" : "Política de contraseñas",
    "Forbid common passwords" : "Restringir contraseñas comunes",
    "Enforce upper and lower case characters" : "Imponer caracteres en mayúsculas y minúsculas",
    "Enforce numeric characters" : "Imponer caracteres numéricos",
    "Enforce special characters" : "Imponer caracteres especiales",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verifica la contraseña contra la lista de contraseñas comprometidas de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Esta verificación crea un resumen de la contraseña y envia los primeros 5 caracteres de este resumen al API haveibeenpwned.com para obtener una lista de todos los resumenes que empezan con ellos. Después verfica en la instancia de Nextcloud si la contraseña está en el juego de resultados.",
    "Unknown error" : "Se presentó un error desconocido",
    "Settings saved" : "Se han guardado las configuraciones "
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
